@@ -6,8 +6,7 @@
 #include <math.h>
 #include <gsl/gsl_matrix.h>
 #include <gsl/gsl_randist.h>
-#include "qsearch/qsearch.h"
-#include "qsearch/qsearch-fulltree.h"
+#include "qsearch.h"
 
 #include <sys/time.h>
 
