@@ -1,11 +1,21 @@
 #ifndef __QSEARCH_H
 #define __QSEARCH_H
 
+#ifdef __cplusplus
+extern "C" {
+#endif
+
 #include "qsearch-neighborlist.h"
 #include "qsearch-tree.h"
 #include "qsearch-treemaster.h"
 #include "qsearch-maketree.h"
+#include "qsearch-fulltree.h"
+#include "clconfig.h"
 
 void qsearch_init(void);
 
+#ifdef __cplusplus
+}
+#endif
+
 #endif
